#ifndef _NWCLIENT_H_
#define _NWCLIENT_H_
/*============================================================================
=  NetWare C NLM Runtime Library source code
=
=  Unpublished Copyright (C) 1997 by Novell, Inc. All rights reserved.
=
=  No part of this file may be duplicated, revised, translated, localized or
=  modified in any manner or compiled, linked or uploaded or downloaded to or
=  from any computer system without the prior written consent of Novell, Inc.
=
=  nwclient.h
==============================================================================
*/
#include <ntypes.h>

#define LOCAL_CONNECTION_OFFSET     0x10000
#define CONN_REFERENCE_OFFSET       0x11111

#define PERMANENT_CONNECTION        0x1000
#define MONITORED_CONNECTION        0x2000

#define IPX_ADDRESS_TYPE            0
#define IPX_ADDRESS_LEN             12


/* Errors */
#define CANNOT_CLOSE_PERMANENT_CONNECTION 1

#define TDS_TAG_IN_USE              0x8842  /* 66 -  */
#define TDS_OUT_OF_MEMORY           0x8843  /* 67 -  */
#define TDS_INVALID_TAG             0x8844  /* 68 - Attempted TDS function with invalid tag */
#define TDS_WRITE_TRUNCATED         0x8845  /* 69 - Attempted TDS write with buffer that exceeded buffer */
#define TDS_READ_TRUNCATED          5

#define NWC_NAME_FORMAT_NDS            0x0001
#define NWC_NAME_FORMAT_BIND           0x0002
#define NWC_NAME_FORMAT_BDP            0x0004      /* This is PNW???? */
#define NWC_NAME_FORMAT_NDS_TREE       0x0008
#define NWC_NAME_FORMAT_WILD           0x8000

#define NWC_STRING_TYPE_ASCII          0x0001
#define NWC_STRING_TYPE_UNICODE        0x0002

#define NWC_TRAN_TYPE_IPX              0x00000001
#define NWC_TRAN_TYPE_UDP              0x00000002
#define NWC_TRAN_TYPE_DDP              0x00000003
#define NWC_TRAN_TYPE_ASP              0x00000004
#define NWC_TRAN_TYPE_WILD             0x80000000

#define NWC_OPEN_LICENSED              0x0001
#define NWC_OPEN_UNLICENSED            0x0002
#define NWC_OPEN_PRIVATE               0x0004
#define NWC_OPEN_PUBLIC                0x0008
#define NWC_OPEN_EXISTING_HANDLE       0x0010
#define NWC_OPEN_DS                    0x0020


#define NWC_CONN_INFO_NONE             0x0000
#define NWC_CONN_INFO_INFO_VERSION     0x0001
#define NWC_CONN_INFO_AUTH_STATE       0x0002
#define NWC_CONN_INFO_BCAST_STATE      0x0003
#define NWC_CONN_INFO_CONN_REF         0x0004
#define NWC_CONN_INFO_TREE_NAME        0x0005
#define NWC_CONN_INFO_SECURITY_STATE   0x0007
#define NWC_CONN_INFO_CONN_NUMBER      0x0008
#define NWC_CONN_INFO_USER_ID          0x0009
#define NWC_CONN_INFO_SERVER_NAME      0x000A
#define NWC_CONN_INFO_TRAN_ADDR        0x000B
#define NWC_CONN_INFO_NDS_STATE        0x000C
#define NWC_CONN_INFO_MAX_PACKET_SIZE  0x000D
#define NWC_CONN_INFO_LICENSE_STATE    0x000E
#define NWC_CONN_INFO_PUBLIC_STATE     0x000F
#define NWC_CONN_INFO_SERVICE_TYPE     0x0010
#define NWC_CONN_INFO_DISTANCE         0x0011
#define NWC_CONN_INFO_SERVER_VERSION   0x0012  /* version 2 */
#define NWC_CONN_INFO_IDENTITY_HANDLE  0x0013  /* version 3 */
#define NWC_CONN_INFO_RETURN_ALL       0xFFFF

#define NWC_INFO_VERSION_1             0x0001
#define NWC_INFO_VERSION_2             0x0002
#define NWC_INFO_VERSION_3             0x0003
#define NWC_INFO_VERSION               NWC_INFO_VERSION_3

#define NWC_AUTHENT_NONE               0x0000
#define NWC_AUTHENT_BIND               0x0001
#define NWC_AUTHENT_NDS                0x0002
#define NWC_AUTHENT_WILD               0x8000

#define NWC_BCAST_PERMIT_ALL           0x0000
#define NWC_BCAST_PERMIT_SYSTEM        0x0001
#define NWC_BCAST_PERMIT_NONE          0x0002
/*  Not currently implemented for NLM
#define NWC_BCAST_PERMIT_SYSTEM_POLLED 0x0003
#define NWC_BCAST_PERMIT_ALL_POLLED    0x0004
*/

#define NWC_SECURITY_SIGNING_NOT_IN_USE   0x00000000
#define NWC_SECURITY_SIGNING_IN_USE       0x00000001
#define NWC_SECURITY_LEVEL_CHECKSUM       0x00000100
#define NWC_SECURITY_LEVEL_SIGN_HEADERS   0x00000200
#define NWC_SECURITY_LEVEL_SIGN_ALL       0x00000400
#define NWC_SECURITY_LEVEL_ENCRYPT        0x00000800

#define NWC_NDS_NOT_CAPABLE            0x0000
#define NWC_NDS_CAPABLE                0x0001

#define NWC_NOT_LICENSED               0x0000
#define NWC_CONNECTION_LICENSED        0x0001
#define NWC_HANDLE_LICENSED            0x0002

#define NWC_CONN_PUBLIC                0x0000
#define NWC_CONN_PRIVATE               0x0001

#define NWC_MATCH_NOT_EQUALS           0x0000
#define NWC_MATCH_EQUALS               0x0001
#define NWC_RETURN_PUBLIC              0x0002
#define NWC_RETURN_PRIVATE             0x0004
#define NWC_RETURN_LICENSED            0x0008
#define NWC_RETURN_UNLICENSED          0x0010

/* printer flags (and print capturing in general) not supported on NLM */
#define NWC_TDS_PRE_ZERO               0x0001
#define NWC_TDS_POST_ZERO              0x0002
#define NWC_TDS_ENCRYPT                0x0004

/* print strings (and print capturing in general) not supported on NLM */
#define NWC_SERVER_NAME_LEN            49
#define NWC_MAX_USER_NAME_LEN          48
#define NWC_SERVICE_TYPE_LEN           49

typedef struct tagNWCTranAddr
{
   nuint32  luType;
   nuint32  luDataLen;
   nuint32  uBuffSize;
   nptr     pBuffer;
} NWCTranAddr, *pNWCTranAddr;

typedef struct tagNWCFrag
{
   nptr     fptr;
   nuint    fsize;
} NWCFrag, *pNWCFrag;

typedef struct tagNWCServerVersion
{
   nuint    uMajorVersion;
   nuint    uMinorVersion;
   nuint    uRevision;
} NWCServerVersion, *pNWCServerVersion;

typedef struct tagNWCString
{
   nuint    uDataType;
   nuint    uBuffSize;
   nuint    uDataLen;
   nptr     pBuffer;
   nuint    uCodePage;
   nuint    uCountryCode;
} NWCString, *pNWCString;

typedef struct tagNWCConnInfo
{
   nuint          uInfoVersion;
   nuint          uAuthenticationState;
   nuint          uBroadcastState;
   nuint32        luConnectionReference;
   pNWCString     pTreeName;
   nptr           pWorkGroupId;
   nuint32        luSecurityState;
   nuint32        luConnectionNumber;
   nuint32        luUserId;
   pNWCString     pServerName;
   pNWCTranAddr   pTranAddr;
   nuint          uNdsState;
   nuint          uMaxPacketSize;
   nuint          uLicenseState;
   nuint          uPublicState;
   pNWCString     pServiceType;
   nuint          uDistance;
   pNWCServerVersion pServerVersion;
   nuint32        luIdentityHandle;
}  NWCConnInfo, *pNWCConnInfo;

/* capture not supported for NLM platform */

#endif
