/******************************************************************************

  %name: nwconnec.h %
  %version: 5 %
  %date_modified: Fri Oct  3 17:52:34 1997 %
  $Copyright:

  Copyright (c) 1989-1995 Novell, Inc.  All Rights Reserved.                      

  THIS WORK IS  SUBJECT  TO  U.S.  AND  INTERNATIONAL  COPYRIGHT  LAWS  AND
  TREATIES.   NO  PART  OF  THIS  WORK MAY BE  USED,  PRACTICED,  PERFORMED
  COPIED, DISTRIBUTED, REVISED, MODIFIED, TRANSLATED,  ABRIDGED, CONDENSED,
  EXPANDED,  COLLECTED,  COMPILED,  LINKED,  RECAST, TRANSFORMED OR ADAPTED
  WITHOUT THE PRIOR WRITTEN CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION
  OF THIS WORK WITHOUT AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO
  CRIMINAL AND CIVIL LIABILITY.$

 *****************************************************************************/

#if ! defined ( NWCONNECT_H )
#define NWCONNECT_H

#if ! defined ( NWCALDEF_H )
# include "nwcaldef.h"
#endif

#include "npackon.h"

#ifdef __cplusplus
extern "C" {
#endif

#define C_SNAMESIZE 48
typedef struct
{
  NWCONN_HANDLE   connID;
  nuint16         connectFlags;
  nuint16         sessionID;
  nuint16         connNumber;
  nuint8          serverAddr[12];
  nuint16         serverType;
  nstr8           serverName[C_SNAMESIZE];
  nuint16         clientType;
  nstr8           clientName[C_SNAMESIZE];
} CONNECT_INFO;

typedef struct
{
   nuint32  systemElapsedTime;
   nuint8   bytesRead[6];
   nuint8   bytesWritten[6];
   nuint32  totalRequestPackets;
} CONN_USE;

typedef struct tNWINET_ADDR
{
  nuint8   networkAddr[4];
  nuint8   netNodeAddr[6];
  nuint16  socket;
  nuint16  connType;  /* 3.11 and above only: 0=not in use, 2=NCP, 3=AFP */
} NWINET_ADDR;

#define CONNECTION_AVAILABLE            0x0001
#define CONNECTION_PRIVATE              0x0002  /* obsolete */
#define CONNECTION_LOGGED_IN            0x0004
#define CONNECTION_LICENSED             0x0004
#define CONNECTION_BROADCAST_AVAILABLE  0x0008
#define CONNECTION_ABORTED              0x0010
#define CONNECTION_REFUSE_GEN_BROADCAST 0x0020
#define CONNECTION_BROADCASTS_DISABLED  0x0040
#define CONNECTION_PRIMARY              0x0080
#define CONNECTION_NDS                  0x0100
#define CONNECTION_PNW                  0x4000  /* obsolete */
#define CONNECTION_AUTHENTICATED        0x8000

/* the following are for NWGetConnInfo */
/* ALL is VLM, OS2 and NT - NOT NETX */
#define NW_CONN_TYPE           1   /* returns nuint16  (VLM) */
#define NW_CONN_BIND      0x0031
#define NW_CONN_NDS       0x0032
#define NW_CONN_PNW       0x0033
#define NW_AUTHENTICATED       3  /* returns nuint16  = 1 if authenticated (ALL)*/
#define NW_PBURST              4  /* returns nuint16  = 1 if pburst (VLM) */
#define NW_VERSION             8  /* returns nuint16  (VLM)  */
#define NW_HARD_COUNT          9  /* returns WORD (VLM)  */
#define NW_CONN_NUM           13  /* returns nuint16  (ALL)  */
#define NW_TRAN_TYPE          15  /* returns nuint16  (VLM)  */
#define NW_TRAN_IPX       0x0021
#define NW_TRAN_TCP       0x0022
#define NW_SESSION_ID     0x8000  /* returns nuint16) (VLM) */
#define NW_SERVER_ADDRESS 0x8001  /* returns 12 byte address (ALL) */
#define NW_SERVER_NAME    0x8002  /* returns 48 byte string  (ALL) */


/* End of new connection model calls. */

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnInfo
(
   NWCONN_HANDLE  connHandle,
   nuint16        type,
   nptr           pData
);

N_EXTERN_LIBRARY( NWCCODE )
NWLockConnection
(
   NWCONN_HANDLE connHandle
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnectionUsageStats
(
   NWCONN_HANDLE  connHandle,
   nuint16        connNumber,
   CONN_USE N_FAR * pStatusBuffer
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnectionInformation
(
   NWCONN_HANDLE  connHandle,
   nuint16        connNumber,
   pnstr8         pObjName,
   pnuint16       pObjType,
   pnuint32       pObjID,
   pnuint8        pLoginTime
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetInternetAddress
(
   NWCONN_HANDLE connHandle,
   nuint16        connNumber,
   pnuint8       pInetAddr
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetInetAddr
(
   NWCONN_HANDLE  connHandle,
   nuint16        connNum,
   NWINET_ADDR N_FAR * pInetAddr
);

N_EXTERN_LIBRARY( void )
NWGetMaximumConnections
(
   pnuint16    pMaxConns
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnectionList
(
   nuint16        Mode,
   NWCONN_HANDLE N_FAR * connListBuffer,
   nuint16        connListSize,
   pnuint16       pNumConns
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnectionStatus
(
   NWCONN_HANDLE        connHandle,
   CONNECT_INFO N_FAR * pConnInfo,
   nuint16              connInfoSize
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnectionNumber
(
   NWCONN_HANDLE        connHandle,
   pnuint16             connNumber
);

N_EXTERN_LIBRARY( NWCCODE )
NWClearConnectionNumber
(
   NWCONN_HANDLE  connHandle,
   nuint16        connNumber
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetDefaultConnRef
(
   pnuint32 pConnReference
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetDefaultConnectionID
(
   NWCONN_HANDLE N_FAR * pConnHandle
);

#define NWGetConnectionID(a, b, c, d) NWGetConnectionHandle(a, b, c, d)

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnectionHandle
(
   pnuint8        pServerName,
   nuint16        reserved1,
   NWCONN_HANDLE N_FAR * pConnHandle,
   pnuint16       reserved2
);

N_EXTERN_LIBRARY( NWCCODE )
NWSetPrimaryConnectionID
(
   NWCONN_HANDLE connHandle
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetPrimaryConnectionID
(
   NWCONN_HANDLE N_FAR * pConnHandle
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetObjectConnectionNumbers
(
   NWCONN_HANDLE        connHandle,
   pnstr8               pObjName,
   nuint16              objType,
   pnuint16             pNumConns,
   pnuint16             pConnHandleList,
   nuint16              maxConns
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetConnListFromObject
(
   NWCONN_HANDLE  connHandle,
   nuint32        objID,
   nuint32        searchConnNum,
   pnuint16       pConnListLen,
   pnuint32       pConnList
);

#ifndef NWOS2
N_EXTERN_LIBRARY( NWCCODE )
NWIsIDInUse
(
   NWCONN_HANDLE connHandle
);

N_EXTERN_LIBRARY( NWCCODE )
NWGetPreferredServer
(
   NWCONN_HANDLE N_FAR * pConnHandle
);

N_EXTERN_LIBRARY( NWCCODE )
NWSetPreferredServer
(
   NWCONN_HANDLE connHandle
);

#else
N_EXTERN_LIBRARY( NWCCODE )
NWResetConnectionConfig
(
   nuint32  flags
);
#endif

#ifdef __cplusplus
}
#endif

#include "npackoff.h"
#endif
