/****************************************************************************
  Source module name:  nwlgui.h
  Release Version:     1.00

  $Workfile:   nwlgui.h  $
  $Revision:   $
  $Modtime::   $
  $Copyright:

  Copyright (c) 1989-1998 Novell, Inc.  All Rights Reserved.                      
         U.S. Patent Number 5,781,724 -- Novell, Inc.

  THIS WORK IS  SUBJECT  TO  U.S.  AND  INTERNATIONAL  COPYRIGHT  LAWS  AND
  TREATIES.   NO  PART  OF  THIS  WORK MAY BE  USED,  PRACTICED,  PERFORMED
  COPIED, DISTRIBUTED, REVISED, MODIFIED, TRANSLATED,  ABRIDGED, CONDENSED,
  EXPANDED,  COLLECTED,  COMPILED,  LINKED,  RECAST, TRANSFORMED OR ADAPTED
  WITHOUT THE PRIOR WRITTEN CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION
  OF THIS WORK WITHOUT AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO
  CRIMINAL AND CIVIL LIABILITY.$

****************************************************************************/

#ifndef NWLOGIN_H
# include <nwlogin.h>
#endif

#ifndef NWLGUI_H
#define NWLGUI_H

#ifdef __cplusplus
extern "C" {
#endif

#define NWLGUI_MAJOR_VER  		1
#define NWLGUI_MINOR_VER		0
#define NWLGUI_REV_VER    		4
				 
#define NWLGUISetVersionP( pVersion ) pVersion->major = NWLGUI_MAJOR_VER;\
pVersion->minor=NWLGUI_MINOR_VER;pVersion->revision = NWLGUI_REV_VER;
#define NWLGUISetVersion( version ) version.major = NWLGUI_MAJOR_VER;\
version.minor=NWLGUI_MINOR_VER;version.revision = NWLGUI_REV_VER;

#define NWLGUIVersionLong( version ) (unsigned long) (version.major * 1000000L \
																+ version.minor * 1000 \
																+ version.revision)
#define NWLGUIVersionLongP( pVersion ) (unsigned long) (pVersion->major * 1000000L \
																+ pVersion->minor * 1000 \
																+ pVersion->revision)
#define NWLGUIVersionLongV( major, minor, revision ) (unsigned long) (major * 1000000L \
																+ minor * 1000 + revision)
#define NWLGUI_CURRENT_VERSION	NWLGUIVersionLongV( NWLGUI_MAJOR_VER, NWLGUI_MINOR_VER, NWLGUI_REV_VER )


#define NWLG_IO_SET_FIELDS	100	/* Runtime update fields on window. */

typedef nint8 NWLG_USAGE_FLAG;

/* NOTE: NWLG_USAGE_FLAGS are *NOT* boolean */
#define NWLG_OPTION_SAVED		0x00	/* Set as saved in registry			*/
#define NWLG_OPTION_ON			0x01	/* Override registry and turn on		*/
#define NWLG_OPTION_OFF			0x02	/* Override registry and turn off	*/

/* Script Tabs (OR these together.) */
#define NWLG_TABS_SAVED			0x00	/* Give tabs as specified in registry */
#define NWLG_LOGIN_TAB			0x01	/* By itself gives simple login		*/
#define NWLG_CONNECTION_TAB	0x02	
#define NWLG_SCRIPT_TAB			0x04
#define NWLG_VARIABLES_TAB		0x08
#define NWLG_ALL_TABS			(NWLG_USAGE_FLAG)0xFF

/* For skipUI only. */
#define NWLG_DISABLE_UI			0x04	/* Prevents UI from ever coming up	*/
												/* If not used, UI comes up if login fails on first try	*/
#if defined(__BORLANDC__)  /* Don't pack the struct. */
#	pragma option -a
#elif defined(N_ARCH_16)
#	pragma pack(2)
#else
#	pragma pack(4)
#endif

typedef struct tagNWLGUIStartInfo
{
	/* Options that may override registry. */
	NWLG_USAGE_FLAG	skipUI;				/* /CONT	 (Initial window doesn't come up)	*/
	NWLG_USAGE_FLAG	autoClose;			/* Close the results window when done?	*/
	NWLG_USAGE_FLAG	saveOnExit;			/* Save latest options to registry		*/
	NWLG_USAGE_FLAG	treeLogin;			/* Is this a tree or server connection	*/
	NWLG_USAGE_FLAG	notebookTabs;		/* Which tabs to be used.					*/

	HANDLE hEvent;								/* GUI Login will SetEvent when processing is done */

	/* Initial state of options.  (Overrides info in NWLGStartInfo.)		*/
   NWLG_USAGE_FLAG	binderyConnOption;	/* Initial state of Bindery conn check box	*/
   NWLG_USAGE_FLAG	clearConnsOption;		/* Initial state of Clear conns check box	*/
   NWLG_USAGE_FLAG	runScriptsOption;		/* Initial state of Run scripts check box	*/

	NWVersion      	APIVersion;				/* Which version of API was caller using?	*/

	NWLGAccessRec		access;				/* access Record to get functions		*/
	nptr					pSystemData;		/* Reserved for use by OS					*/
	nptr					pData;				/* Reserved										*/

	NWLG_USAGE_FLAG	displayResults;	/* Display the results window or not	*/

	pNWLGStringElement	treeHistoryList;		/* History list for tree combo	*/
	pNWLGStringElement	serverHistoryList;	/* History list for server combo	*/
	pNWLGStringElement	contextHistoryList;	/* History list for context combo*/
	pNWLGStringElement	scriptHistoryList;	/* History list for script combo	*/
	pNWLGStringElement	profileHistoryList;	/* History list for profile combo*/
} NWLGUIStartInfo;

typedef NWLGUIStartInfo           N_FAR * pNWLGUIStartInfo;

#if defined(__BORLANDC__)	/* Restore to compiler specified. */
#	pragma option -a.
#else
#	pragma pack()
#endif

/* End of UIStartInfo                                                      */
/***************************************************************************/

   N_EXTERN_LIBRARY( NWCCODE )
   NWLoginUI
   (
   	pnstr lpszCmdLine,
   	pNWLGStartInfo startInfo,
   	pNWLGUIStartInfo uiInfo
   );

   /* pNWLoginUI is a typedef for type of function NWLoginUI is. */
   N_TYPEDEF_CALLBACK( NWCCODE, pNWLoginUI )
   (
   	pnstr lpszCmdLine,
   	pNWLGStartInfo startInfo,
   	pNWLGUIStartInfo uiInfo
   );
#ifdef __cplusplus
}
#endif
#endif
