/*
//ͻ
// (c) 1993 Novell, Inc.	All rights reserved.                              
//																								  
// THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND		  
// TREATIES.																					  
//																								  
// NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED, COPIED,			  
// DISTRIBUTED, REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED,         
// EXPANDED, COLLECTED, COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED	  
// WITHOUT THE PRIOR WRITTEN CONSENT OF NOVELL, INC.                        
//																								  
// ANY USE OR EXPLOITATION OF THIS WORK WITHOUT AUTHORIZATION COULD SUBJECT 
// THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.								  
//͹
// Source module name: NWPSCFGX.H														  
//ͼ
*/
/****************************************************************************/
/**  N W P S C f g x x x x x x x x x	C a l l s  ***************************/
/****************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

/*++++++++++++ calls to make attribute name/number conversions +++++++++++++*/
/*==========================================================
  Convert an attribute name to a print service attribute id.
  If the name can not be mapped, a -1 is returned.
  ==========================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAttrNameToNumber(
  pnstr8    attrName);				 /* Attribute name */

/*==========================================================
  Convert a print service attribute id to an attribute name.
  if the attribute id is invalid a NULL is returned.
  ==========================================================*/
N_EXTERN_LIBRARY(pnstr8)
NWPSCfgAttrNumberToName(
  nuint	attrID);                    /* Attribute Number */

/*===================================================================
  Get the default settings for a specified printer type.
  PrinterType should be NWPS_DEFAULT or NWPS_P_xxx.
  SubType is the port number for Parallel and Serial printers.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetPrinterDefaults(
  nuint	printerType,					 /* Type of printer defaults */
  nuint	subtype,                    /* Device SubType (Port) value	*/
  NWPS_PConfig NWPTR pconfig);		/* Buffer to store defaults in  */

/*===============================================================
  Information stored in the bindery configuration file has a
  different format than NWPS_PConfig.	Those applications needing
  the old format can use these calls to do the conversion.
  ===============================================================*/
N_EXTERN_LIBRARY(void)
NWPSApiConfigToFileConfig(
  pnstr8    name,
  NWPS_PConfig NWPTR apiConfig,
  pnuint8	 fileConfig);

N_EXTERN_LIBRARY(void)
NWPSFileConfigToApiConfig(
  pnuint8	fileConfig,
  pnstr8    name,
  pnuint32	length,
  NWPS_PConfig NWPTR apiConfig);

/*========== calls to change the print server list =========================*/
/*
PSERVER ATTRIBUTE    ATTRIB VALUE	  DEFAULT		 MULTI-VALUED
-----------------    ------------	  -------		 ------------
NWPS_ATTR_ACL			Object_ACL_T	  PServer R/W		  YES
NWPS_ATTR_CN			char[]			  PServer name      NO
NWPS_ATTR_DESC       char[]			  " "               NO
NWPS_ATTR_HOST_DEV	char[]			  (none)            NO
NWPS_ATTR_L          char[]			  (none)            YES
NWPS_ATTR_NADD       Net_Address_T	  (none)            YES
NWPS_ATTR_O          char[]			  (none)            YES
NWPS_ATTR_OPER       NWPS_Typed_Name  current user      YES
NWPS_ATTR_OU			char[]			  (none)            YES
NWPS_ATTR_PRINTER    Typed_Name_T	  (none)            YES
NWPS_ATTR_PRIV_KEY	Octet_String_T   (none)            NO
NWPS_ATTR_PUBL_KEY	Octet_String_T   (none)            NO
NWPS_ATTR_SAP			char[]			  (none)            NO
NWPS_ATTR_SEE_ALSO	char[]			  (none)            YES
NWPS_ATTR_STAT       Integer_T		  NWPS_DOWN         NO
NWPS_ATTR_USER       NWPS_Typed_Name  current OU		  YES
NWPS_ATTR_VERS       char[]			  (none)            NO
*/

/*===================================================================
  Create a new Print Server object in the bindery/directory.
  A default Operator and User is created.  In the bindery the
  operator is SUPERVISOR and the user is group EVERYONE.  In the
  directory the operator is the current user and the user is
  the current Organizational Unit.	A password is also created.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/

N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddPrintServer(
  nuint		connType,				 /* directory or bindery flag */
  nuint32	connID,					 /* connection identifier */
  pnstr8    pServerName);			 /* Name of print server to add */

/*===================================================================
  Delete a Print Server. Any configuration information is also
  removed from the bindery/directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeletePrintServer(
  nuint		connType,				 /* directory or bindery flag */
  nuint32	connID,					 /* connection identifier */
  pnstr8    pServerName);			 /* Name of print server to delete */ 

/*===================================================================
  Find the first print server.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstPrintServer(
  nuint	connType,						 /* Directory or bindery flag */
  nuint32 connID,                   /* Connection identifier */
  NWPSListHandle NWPTR handle,		/* returned handle */
  pnstr8    pServerName);			 /* Name of print server */ 

/*===================================================================
  Find the next print server.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextPrintServer(
  NWPSListHandle handle,				/* handle for list of print servers */
  pnstr8    pServerName);			 /* Name of print server */ 

/*===================================================================
  End scanning for print servers.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextPrintServer(
  NWPSListHandle handle);				/* handle for list of print servers */

/*===================================================================
  verify the print server.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgVerifyPrintServer(
  nuint		connType,						 /* Directory or bindery flag */
  nuint32	connID,						  /* Connection identifier */
  pnstr8    pServerName);			 /* Name of print server */ 

/*===================================================================
  Create a print server attribute in the bindery/directory.
  Attributes that do not exist in the bindery will fail (Sorry).
  See above for the list of legal attributes.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddPrintServerAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  nuint		attrID,							 /* attribute name identifier */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Delete a print server attribute from the bindery/directory.
  Attributes that do not exist in the bindery will fail (Sorry).
  See above for the list of legal attributes.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeletePrintServerAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  nuint		attrID,							 /* attribute name identifier */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Find the first attribute value in the bindery or directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstPrintServerAttr(
  nuint		connType,						 /* directory or bindery flag */ 
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  nuint		attrID,							 /* attribute name identifier */
  NWPSListHandle NWPTR handle,		/* returned handle */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Find the next attribute value in the bindery or directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextPrintServerAttr(
  NWPSListHandle handle,				/* handle for the list of print 
													server attributes */
  pnstr8    pServerName,			 /* name of the print server */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  End scanning for attribute values in the bindery or directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextPrintServerAttr(
  NWPSListHandle handle);				/* handle for the list of print 
													server attributes */


/*===================================================================
  Modify an attribute value in the bindery or directory.
  If the attribute is single valued, the AddPrintServerAttr()
  will perform almost the same function.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgModifyPrintServerAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  nuint		attrID,							 /* attribute name identifier */
  nptr		oldValue,				 /* pointer to the old attribute value */
  nptr		newValue);				 /* pointer to the new attribute value */


/* calls to change the file server list */
/*
FSERVER ATTRIBUTE    ATTRIB VALUE	  DEFAULT		 MULTI-VALUED
-----------------    ------------	  -------		 ------------
(none)
*/
/*===================================================================
  Add a new file server for the print server to use.	Since print
  servers are context oriented in directory services, this call
  does not make sense and will fail in directory services mode.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddNServer(
  nuint		connType,						 /* Directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    nServerName);			 /* Name of NetWare server to add */

/*===================================================================
  Delete a file server from the print server's service list.
  Since file servers are context oriented in directory services,
  this call does not make sense and will fail in directory mode.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeleteNServer(
  nuint		connType,						 /* Directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    nServerName);			 /* Name of NetWare server to delete */

/*===================================================================
  Find the first file server from the print server's service list.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstNServer(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  NWPSListHandle NWPTR handle,		/* returned handle */
  pnstr8    nServerName);			 /* Name of found NetWare server */

/*===================================================================
  Find the next file server from the print server's service list.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextNServer(
  NWPSListHandle handle,				/* handle for the list of 
													NetWare servers */
  pnstr8    nServerName);			 /* Name of found NetWare server */

/*===================================================================
  End scanning file servers from the print server's service list.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextNServer(
  NWPSListHandle handle);				/* handle for the list of 
													NetWare servers */

/*===================================================================
  Find the file server from the print server's service list.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgVerifyNServer(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    nServerName);			 /* Name of found NetWare server */


/* calls to change the printer configuration */
/*
PRINTER ATTRIBUTE    ATTRIB VALUE	  DEFAULT		 MULTI-VALUED
-----------------    ------------	  -------		 ------------
NWPS_ATTR_ACL			Object_ACL_T	  printer R/W		  YES
NWPS_ATTR_CART       char[]			  (none)            YES
NWPS_ATTR_CN			char[]			  printer name      NO
NWPS_ATTR_CONF       Octet_String_T   LPT1				  NO
NWPS_ATTR_DESC       char[]			  " "               NO
NWPS_ATTR_DQUEUE		char[]			  (none)            NO
NWPS_ATTR_HOST_DEV	char[]			  (none)            NO
NWPS_ATTR_L          char[]			  (none)            YES
NWPS_ATTR_MEMORY		Integer_T		  (none)            NO
NWPS_ATTR_NADD       Net_Address_T	  (none)            YES
NWPS_ATTR_NADD_REST	Net_Address_T	  (none)            YES
NWPS_ATTR_NOTIFY		NWPS_Typed_Name  Job Owner         YES
NWPS_ATTR_O          char[]			  (none)            YES
NWPS_ATTR_OPER       NWPS_Typed_Name  current user      YES
NWPS_ATTR_OU			char[]			  (none)            YES
NWPS_ATTR_OWNER		NWPS_Typed_Name  current user      YES
NWPS_ATTR_PAGE       char[]			  (none)            YES
NWPS_ATTR_PRINT_SER	Typed_Name_T	  pServer/number	  NO
NWPS_ATTR_QUEUE		Typed_Name_T	  (none)            YES
NWPS_ATTR_SEE_ALSO	char[]			  (none)            YES
NWPS_ATTR_SERIAL		char[]			  (none)            YES
NWPS_ATTR_STAT       Integer_T	 NWPS_PSTAT_NOT_CONNECTED	NO
NWPS_ATTR_TYPE(faces)char[]			  (none)            YES
*/

/*===================================================================
  Create a new printer object.
  Printer number is required for bindery identification only.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddPrinter(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    printerName,			 /* Name of the Printer to add */
  pnuint    printerNumber);		 /* Number of the Printer to add */

/*===================================================================
  Delete a printer from the bindery/directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeletePrinter(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    printerName);			 /* Name of printer to delete */ 

/*===================================================================
  Find the first printer in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstPrinter(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  NWPSListHandle NWPTR handle,		/* returned handle */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    printerName);			 /* Name of the Printer sought */

/*===================================================================
  Find the next printer in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextPrinter(
  NWPSListHandle handle,				/* handle for the list of printers */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    printerName);			 /* Name of the Printer sought */

/*===================================================================
  End scan for printers in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextPrinter(
  NWPSListHandle handle);				/* handle for the list of printers */

/*===================================================================
  Find the printer in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgVerifyPrinter(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* Name of print server */ 
  pnstr8    printerName);			 /* Name of the Printer to verify */

/*===================================================================
  Add a printer attribute to the bindery/directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddPrinterAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  pnstr8    printerName,			 /* name of the printer */
  nuint		attrID,							 /* attribute name identifier */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Delete a printer attribute from the bindery/directory.
  See AddPrinterAttr for a list of legal bindery attributes.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeletePrinterAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  pnstr8    printerName,			 /* name of the printer */
  nuint		attrID,							 /* attribute name identifier */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Find the first printer attribute in the bindery/directory.
  See AddPrinterAttr for a list of legal bindery attributes.
  attrValue should be a buffer large enough to hold each attribute value.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstPrinterAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  pnstr8    printerName,			 /* name of the printer */
  nuint		attrID,							 /* attribute name identifier */
  NWPSListHandle NWPTR handle,		/* returned handle */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Find the next printer attribute in the bindery/directory.
  attrValue should be a buffer large enough to hold each attribute value.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextPrinterAttr(
  NWPSListHandle handle,				/* handle to the list of printer 
													attributes */
  pnstr8    printerName,			 /* name of the printer */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  End scan for printer attributes in the bindery/directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextPrinterAttr(
  NWPSListHandle handle);				/* handle to the list of printer 
													attributes */

/*===================================================================
  Change a printer attribute in the bindery/directory.
  This function is similar to a add attribute to a single value
  attribute, however, some attributes must be changed in one call.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgModifyPrinterAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    pServerName,			 /* name of the print server */
  pnstr8    printerName,			 /* name of the printer */
  nuint		attrID,							 /* attribute name identifier */
  nptr		oldValue,				 /* pointer to old attribute buffer */
  nptr		newValue);				 /* pointer to new attribute buffer */


/* calls to change a printer's queue list */
/*
QUEUE ATTRIBUTE		ATTRIB VALUE	  DEFAULT		 MULTI-VALUED
-----------------    ------------	  -------		 ------------
NWPS_ATTR_ACL			Object_ACL_T	  queue R/W         YES
NWPS_ATTR_CN			char[]			  printer name      NO
NWPS_ATTR_DESC       char[]			  " "               NO
NWPS_ATTR_DEVICE		char[]			  (none)            YES
NWPS_ATTR_HOST_RES	char[]			  (none)            NO
NWPS_ATTR_HOST_SER	char[]			  NetWare Server	  NO
NWPS_ATTR_L          char[]			  (none)            YES
NWPS_ATTR_NADD       Net_Address_T	  (none)            YES
NWPS_ATTR_O          char[]			  (none)            YES
NWPS_ATTR_OPER       NWPS_Typed_Name  current user      YES
NWPS_ATTR_OU			char[]			  (none)            YES
NWPS_ATTR_QUE_DIR    char[]			  <Vol>:\QUEUE\<ID>.QDR  YES
NWPS_ATTR_SEE_ALSO	char[]			  (none)            YES
NWPS_ATTR_SERVER		char[]			  (none)            YES
NWPS_ATTR_USER       NWPS_Typed_Name  current OU		  YES
NWPS_ATTR_VOLUME		char[]			  Volume            NO
*/

/*===================================================================
  Add a print queue to the bindery/directory.  In bindery mode,
  the volumeName is automatically assigned.	In both modes,
  default values are added for the following fields;
		Description, Queue Directory, Operator, User and Volume.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddPrintQueue(
  nuint		connType,							 /* directory or bindery flag */
  nuint32	connID,							  /* connection identifier */
  pnstr8    queueName,					 /* Name of the print queue */ 
  pnstr8    volumeName);				 /* Name of the print queue's volume */ 

/*===================================================================
  Delete a print queue from the bindery/directory.  Any reference
  to the queue is also removed from Printers and Print Servers
  that are within the same context as the Print Queue.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeletePrintQueue(
  nuint		connType,							 /* directory or bindery flag */
  nuint32	connID,							  /* connection identifier */
  pnstr8    queueName);              /* Name of the queue to delete */

/*===================================================================
  Find the first print queue in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstPrintQueue(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  NWPSListHandle NWPTR handle,		/* returned handle */
  pnstr8    queueName);           /* Name of the print queue */ 

/*===================================================================
  Find the next print queue in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextPrintQueue(
  NWPSListHandle handle,				/* handle to the list of Print Queues */
  pnstr8    queueName);           /* Name of the print queue */ 

/*===================================================================
  End scan for print queues in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextPrintQueue(
  NWPSListHandle handle);				/* handle to the list of Print Queues */

/*===================================================================
  Find the print queue in the directory/bindery.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgVerifyPrintQueue(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    queueName);           /* Name of the print queue */ 

/*===================================================================
  Create or Add a Print Queue attribute to the bindery/directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgAddPrintQueueAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    queueName,				 /* name of the print queue */
  nuint		attrID,							 /* attribute name identifier */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Delete a Print Queue attribute from the bindery/directory.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgDeletePrintQueueAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    queueName,				 /* name of the print queue */
  nuint		attrID,							 /* attribute name identifier */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Find the first attribute for the Print Queue.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetFirstPrintQueueAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    queueName,				 /* name of the print queue */
  nuint		attrID,							 /* attribute name identifier */
  NWPSListHandle NWPTR handle,		/* returned handle */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  Find the next attribute for the Print Queue.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgGetNextPrintQueueAttr(
  NWPSListHandle handle,				/* handle to the list of Print 
													Queue attributes */
  pnstr8    queueName,				 /* name of the print queue */
  nptr		attrValue);           /* pointer to attribute buffer */

/*===================================================================
  End scan for attributes for the Print Queue.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgEndNextPrintQueueAttr(
  NWPSListHandle handle);				/* handle to the list of Print 
													Queue attributes */

/*===================================================================
  Modify an attribute for the Print Queue.
  A zero is returned on succecss, or a non-zero error code on failure
  ===================================================================*/
N_EXTERN_LIBRARY(NWCCODE)
NWPSCfgModifyPrintQueueAttr(
  nuint		connType,						 /* directory or bindery flag */
  nuint32	connID,						  /* connection identifier */
  pnstr8    queueName,				 /* name of the print queue */
  nuint		attrID,							 /* attribute name identifier */
  nptr		oldValue,				 /* pointer to old attribute buffer */
  nptr		newValue);				 /* pointer to new attribute buffer */

#ifdef __cplusplus
}
#endif

