#ifndef __unistd_h__
#define __unistd_h__
/*============================================================================
=  Novell Software Development Kit
=
=  Copyright (C) 1999-2002 Novell, Inc. All Rights Reserved.
=
=  This work is subject to U.S. and international copyright laws and treaties.
=  Use and redistribution of this work is subject  to  the  license  agreement
=  accompanying  the  software  development kit (SDK) that contains this work.
=  However, no part of this work may be revised and/or  modified  without  the
=  prior  written consent of Novell, Inc. Any use or exploitation of this work
=  without authorization could subject the perpetrator to criminal  and  civil
=  liability.
=
=  Source(s): ISO/IEC (POSIX) 9845:1996; Novell additions
=
=  unistd.h
==============================================================================
*/
#include <stdarg.h>
#include <stddef.h>
#include <sys/unistd.h>

/* 'mode' values for access(), shm_open(), etc. ...                  */
#define R_OK          1 /* test for read permission                  */
#define W_OK          2 /* test for write permission                 */
#define X_OK          4 /* test for execute permission               */
#define F_OK          8 /* test for existence of file                */

/* values for 'whence' in lseek()...                                 */
#define SEEK_SET      0 /* set file pointer to 'offset'              */
#define SEEK_CUR      1 /* set file pointer to current plus 'offset' */
#define SEEK_END      2 /* set file pointer to EOF plus 'offset'     */

/* old Berkeley names...                                             */
#define L_SET         SEEK_SET
#define L_INCR        SEEK_CUR
#define L_XTND        SEEK_END

#define EFF_ONLY_OK   8 /* test using effective ids                  */

#define STDIN_FILENO  0 /* descriptor underlying 'stdin'             */
#define STDOUT_FILENO 1 /* ibid for 'stdout'                         */
#define STDERR_FILENO 2 /* ibid for 'stderr'                         */

/* flags for process()...                                            */
#define PROC_DETACHED      1  /* detached process (not a child)      */
#define PROC_CURRENT_SPACE 4  /* use current NetWare address space   */
#define PROC_MEMORY_DEBUG  8  /* guard page at end of allocations    */

/* standard console wiring for process()...                          */
typedef struct
{
#define FD_UNUSED  -1  /* ignore: do not wire the console            */
   int   infd;         /* new process' standard input, etc.          */
   int   outfd;
   int   errfd;
} wiring_t;


#ifdef __cplusplus
extern "C"
{
#endif

/* POSIX-defined functions... */
int          access   ( const char *path, int mode );
unsigned int alarm    ( unsigned int seconds );
int          chdir    ( const char *path );
int          chsize   ( int fildes, size_t size );
int          close    ( int fildes );
int          dup      ( int fildes );
int          dup2     ( int fildes1, int fildes2 );
void         _exit    ( int status );
int          fdatasync( int fildes );
int          fsync    ( int fildes );
long         fpathconf( int fildes, int name );
int          ftruncate( int fildes, off_t len );
char        *getcwd   ( char *path, size_t len );
int          getopt   ( int argc, char * const argv[], const char *optstr );
int          ioctl    ( int, int, ... );
int          isatty   ( int fildes );
off_t        lseek    ( int fildes, off_t offset, int whence );
long         pathconf ( const char *path, int name );
int          pipe     ( int fildes[2] );
ssize_t      pread    ( int fildes, void *buf, size_t nbytes, off_t off );
ssize_t      pwrite   ( int fildes, const void *buf, size_t nbytes, off_t off );
ssize_t      read     ( int fildes, void *buf, size_t nbytes );
int          rmdir    ( const char *path );
long         sysconf  ( int name );
int          unlink   ( const char *path );
ssize_t      write    ( int fildes, const void *buf, size_t nbytes );

/* nonstandard additions... */
int          cancel   ( int t_id );
int          chdir2   ( const char *path );
size_t       confstr  ( int name, char *buf, size_t len );
//int          delay    ( unsigned int milliseconds );
int          eof      ( int fildes );
pid_t        processve( const char *path, unsigned long flags,
                        const char *env[], wiring_t *wiring,
                        struct fd_set *fds, void *reserved,
                        const char *argv[] );
pid_t        processle( const char *path, unsigned long flags,
                        const char *env[], wiring_t *wiring,
                        struct fd_set *fds, void *reserved,
                        const char *arg0, ... );
int          setmode  ( int fildes, int oflag );
unsigned int sleep    ( unsigned int seconds );
off_t        tell     ( int fildes );

/* nonstandard (transitional) addtions for 64-bit file I/O... */
int      chsize64     ( int fildes, size64_t size );
int      ftruncate64  ( int fildes, off64_t len );
off64_t  lseek64      ( int fildes, off64_t offset, int whence );
ssize_t  pread64      ( int fildes, void *buf, size_t nbytes, off64_t off );
ssize_t  pwrite64     ( int fildes, const void *buf, size_t nbytes,off64_t off);
off64_t  tell64       ( int fildes );

char **___environ ( void );
char **___optarg  ( void );
int   *___optind  ( void );
int   *___opterr  ( void );
int   *___optopt  ( void );
int   *___optreset( void );


#ifdef __cplusplus
}
#endif

#define environ  (___environ())

/* globals for getopt() implementation... */
#define optarg   (*___optarg())
#define optind   (*___optind())
#define opterr   (*___opterr())
#define optopt   (*___optopt())
#define optreset (*___optreset())


/* sleep() as implemented on NetWare is missing full POSIX semantics... */
#define sleep(t)        delay((t)*1000)

/* path analysis/parsing 'type' and 'flags' arguments for [de]construct()  */
#define PATH_UNDEF      0x00000000
#define PATH_DOS        PATH_UNDEF  /* indicates potential DOS path          */
#define PATH_UNC        0x00000001  /* double slash found at beginning       */
#define PATH_UNIX       0x00000002  /* forward slashes only                  */
#define PATH_NETWARE    0x00000004  /* slash and colon followed by slashes   */
#define PATH_MACINTOSH  0x00000008  /* only colons                           */
#define PATH_ROOTED     0x00000010  /* starts with delimiter                 */
#define PATH_VOLROOTED  0x00000020  /* volume plus colon appears             */
#define PATH_EXTENSION  0x00000040  /* contains period                       */
#define PATH_HIERARCHY  0x00000080  /* at least one subdirectory element     */
#define PATH_SHORTNAME  0x00000100  /* 8.3 names only                        */
#define PATH_LONGNAME   0x00000200  /* at least one element greater than 8.3 */
#define PATH_ENDED      0x00000400  /* ends in delimiter                     */
#define PATH_DOSDRIVE   0x00001000  /* single-letter drive, colon and path   */
#define PATH_MIXEDCASE  0x00002000  /* at least one element in mixed case    */
#define PATH_DOTS       0x00004000  /* path contains dots                    */
#define PATH_SLASH      0x00008000  /* path contains a slash                 */
#define PATH_BACKSLASH  0x00010000  /* path contains a backslash             */
#define PATH_COLON      0x00020000  /* path contains a colon                 */
#define PATH_ILLEGAL    0x80000000  /* illegal character or combination      */
#define PATH_MIXED      (PATH_SHORT|PATH_LONG)


#ifdef __cplusplus
extern "C"
{
#endif

int deconstruct( const char *path, char *server, char *volume, char *directory,
            char *name, char *extension, int *elements, int *flags );
int construct  ( char *path, char *server, char *volume, char *directory,
            char *name, char *extension, int flags );


#ifdef __cplusplus
}
#endif

#define _POSIX_MAPPED_FILES          1
#define _POSIX_MEMLOCK               1
#define _POSIX_MEMLOCK_RANGE         1
#define _POSIX_MEMORY_PROTECTION     1
#define _POSIX_SYNCHRONIZED_IO       1
#define _POSIX_FSYNC                 1

#define _POSIX_ASYNC_IO             -1
#define _POSIX_CHOWN_RESTRICTED     -1
#define _POSIX_NO_TRUNC             -1
#define _POSIX_PRIO_IO              -1
#define _POSIX_SYNC_IO               1
#define _POSIX_VDISABLE              1

#endif
